[![Documentation Status](https://readthedocs.org/projects/rjwt/badge/?version=latest)](https://rjwt.readthedocs.io/en/latest/?badge=latest)  


A Python library for constructing, signing, and validating recursive Javascript Web Tokens.
This is a specialized application of [Javascript Web Tokens](https://jwt.io/) for highly distributed systems.

documentation: https://rjwt.readthedocs.io/en/latest/
